@@ -427,7 +427,8 @@ static int show_fkey(int key)
     if( cm->fkeyhelp[fkey].textname ) {
 	 int slent = strlen(cm->fkeyhelp[fkey].textname);
          if (slent>4 &&
-	     strcmp(cm->fkeyhelp[fkey].textname+slent-4,".txt")) {
+	     (strcmp(cm->fkeyhelp[fkey].textname+slent-4,".txt")
+         || strcmp(cm->fkeyhelp[fkey].textname+slent-4,".msg"))) {
 	     return fkey;
 	 }
     }
